@@ -1,10 +1,10 @@
 /////////////////////////////////////////////////////////////////////////////
-// Name:        accel.h
+// Name:        wx/motif/accel.h
 // Purpose:     wxAcceleratorTable class
 // Author:      Julian Smart
 // Modified by:
 // Created:     17/09/98
-// RCS-ID:      $Id: accel.h,v 1.10 2004/05/23 20:51:21 JS Exp $
+// RCS-ID:      $Id: accel.h 42752 2006-10-30 19:26:48Z VZ $
 // Copyright:   (c) Julian Smart
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -12,10 +12,6 @@
 #ifndef _WX_ACCEL_H_
 #define _WX_ACCEL_H_
 
-#if defined(__GNUG__) && !defined(NO_GCC_PRAGMA)
-#pragma interface "accel.h"
-#endif
-
 #include "wx/object.h"
 #include "wx/string.h"
 #include "wx/event.h"
@@ -27,19 +23,12 @@ public:
     wxAcceleratorTable();
     wxAcceleratorTable(const wxString& resource); // Load from .rc resource
     wxAcceleratorTable(int n, const wxAcceleratorEntry entries[]); // Load from array
-    
-    // Copy constructors
-    wxAcceleratorTable(const wxAcceleratorTable& accel) { Ref(accel); }
-    wxAcceleratorTable(const wxAcceleratorTable* accel) { if (accel) Ref(*accel); }
-    
-    ~wxAcceleratorTable();
-    
-    wxAcceleratorTable& operator = (const wxAcceleratorTable& accel) { if (*this == accel) return (*this); Ref(accel); return *this; }
-    bool operator == (const wxAcceleratorTable& accel) { return m_refData == accel.m_refData; }
-    bool operator != (const wxAcceleratorTable& accel) { return m_refData != accel.m_refData; }
-    
-    bool Ok() const;
-    
+
+    virtual ~wxAcceleratorTable();
+
+    bool Ok() const { return IsOk(); }
+    bool IsOk() const;
+
     // Implementation only
     int GetCount() const;
     wxAcceleratorEntry* GetEntries() const;
