@@ -4,7 +4,7 @@
 // Author:      David Webster
 // Modified by:
 // Created:     09/09/99
-// RCS-ID:      $Id: dcmemory.h,v 1.11 2004/05/23 20:51:38 JS Exp $
+// RCS-ID:      $Id: dcmemory.h 42755 2006-10-30 19:41:46Z VZ $
 // Copyright:   (c) David Webster
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -14,18 +14,20 @@
 
 #include "wx/dcclient.h"
 
-class WXDLLEXPORT wxMemoryDC: public wxDC
+class WXDLLEXPORT wxMemoryDC: public wxDC, public wxMemoryDCBase
 {
 public:
-    wxMemoryDC(void);
+    wxMemoryDC() { CreateCompatible(NULL); Init(); }
+    wxMemoryDC(wxBitmap& bitmap) { CreateCompatible(NULL); Init(); SelectObject(bitmap); }
     wxMemoryDC(wxDC* pDC); // Create compatible DC
 
-    virtual void SelectObject(const wxBitmap& rBitmap);
 protected:
     // override some base class virtuals
     virtual void DoGetSize( int* pWidth
                            ,int* pHeight
                           ) const;
+    virtual void DoSelect(const wxBitmap& bitmap);
+
     // create DC compatible with the given one or screen if dc == NULL
     bool CreateCompatible(wxDC* pDC);
 
